import { ScrollingUtil, TourState, TourService, TourBackdropService, TourHotkeyListenerComponent, TourModule } from 'ngx-ui-tour-core';
export * from 'ngx-ui-tour-core';
import { CommonModule } from '@angular/common';
import { Directive, ElementRef, Input, NgModule } from '@angular/core';
import { NgbPopoverModule } from '@ng-bootstrap/ng-bootstrap';

class TourAnchorConsoleDirective {
    constructor(tourService, element, tourBackdrop) {
        this.tourService = tourService;
        this.element = element;
        this.tourBackdrop = tourBackdrop;
    }
    ngOnInit() {
        this.tourService.register(this.tourAnchor, this);
    }
    ngOnDestroy() {
        this.tourService.unregister(this.tourAnchor);
    }
    // noinspection JSUnusedGlobalSymbols
    showTourStep(step) {
        const htmlElement = this.element.nativeElement;
        if (!step.preventScrolling) {
            ScrollingUtil.ensureVisible(htmlElement);
        }
        if (step.enableBackdrop) {
            this.tourBackdrop.show(this.element);
        }
        else {
            this.tourBackdrop.close();
        }
        console.group(step.title);
        console.log(step.content);
        console.log(`${step.placement || 'above'} ${this.tourAnchor}`);
        console.groupEnd();
    }
    hideTourStep() {
        if (this.tourService.getStatus() === TourState.OFF) {
            this.tourBackdrop.close();
        }
    }
}
TourAnchorConsoleDirective.decorators = [
    { type: Directive, args: [{
                selector: '[tourAnchor]',
            },] }
];
TourAnchorConsoleDirective.ctorParameters = () => [
    { type: TourService },
    { type: ElementRef },
    { type: TourBackdropService }
];
TourAnchorConsoleDirective.propDecorators = {
    tourAnchor: [{ type: Input }]
};

class TourConsoleModule {
    static forRoot() {
        return {
            ngModule: TourConsoleModule,
            providers: [
                TourService,
                TourBackdropService
            ],
        };
    }
}
TourConsoleModule.decorators = [
    { type: NgModule, args: [{
                declarations: [TourAnchorConsoleDirective],
                exports: [TourAnchorConsoleDirective, TourHotkeyListenerComponent],
                imports: [TourModule, CommonModule, NgbPopoverModule],
            },] }
];

/*
 * Public API Surface of ngx-ui-tour-console
 */

/**
 * Generated bundle index. Do not edit.
 */

export { TourAnchorConsoleDirective, TourConsoleModule };
//# sourceMappingURL=ngx-ui-tour-console.js.map
